%EXAMPLE 1.9-2 Cryogenic_Current_Leads
%Heat Transfer
%G.F. Nellis and S.A. Klein
%Cambridge University Press, 2009
%
%INPUTS
% D - diameter of current lead (m)
% N - number of nodes
%
%OUTPUTS
%q_dot_c - heat transfer rate 

function[x,T]=EXAMPLE1p9_2(D,N)

I=100; 				%current (amp)
T_h=20+273.2;       %hot temperature (K)
T_c=50;             %cold temperature (K)
L=1;				%length of lead (m)
eps=0.5;			%emissivity of lead surface (-)
sigma=5.67e-8;		%Stefan-Boltzmann constant (W/m^2-K^4)

%Position nodes
for i=1:N
   x(i,1)=(i-1)*L/(N-1);	%position of each node (m)
end
DELTAx=L/(N-1);				%distance between adjacent nodes (m)

%Start relaxation with a linear temperature distribution
for i=1:N
   Tg(i,1)=T_h-(T_h-T_c)*(i-1)/(N-1);
end

%Setup A and b
A=spalloc(N,N,3*N);
b=zeros(N,1);

err=999;				%error that terminates the while loop
tol=0.1;				%criteria for terminating the while loop
while(err>tol)
   %specify the hot end temperature
   A(1,1)=1;
   b(1,1)=T_h;
   %specify the cold end temperature
   A(N,N)=1;
   b(N,1)=T_c;
   %internal nodes
   for i=2:(N-1)
      A(i,i)=-k_cu((Tg(i+1,1)+Tg(i,1))/2)*pi*D^2/(4*DELTAx)-...
          k_cu((Tg(i-1,1)+Tg(i,1))/2)*pi*D^2/(4*DELTAx)-...
          sigma*eps*pi*D*DELTAx*(Tg(i,1)^2+T_h^2)*(Tg(i,1)+T_h);
      A(i,i-1)=k_cu((Tg(i-1,1)+Tg(i,1))/2)*pi*D^2/(4*DELTAx);
      A(i,i+1)=k_cu((Tg(i+1,1)+Tg(i,1))/2)*pi*D^2/(4*DELTAx);
      b(i,1)=-rho_e_cu(Tg(i,1))*4*DELTAx*I^2/(pi*D^2)-...
          sigma*eps*pi*D*DELTAx*(Tg(i,1)^2+T_h^2)*(Tg(i,1)+T_h)*T_h;
   end

   T=full(A\b);
   err=sum(abs(T-Tg))/N
   Tg=T;
end
 
q_dot_c=k_cu((Tg(N)+Tg(N-1))/2)*pi*D^2*(T(N-1)-T(N))/(4*DELTAx);
    %heat transfer to cold end

% %constant property analytical solution
% g_dot_vol=16*I^2*rho_e_cu(T_h)/(pi^2*D^4);
% for i=1:N
%    T_an(i,1)=g_dot_vol*L^2*((x(i)/L)-(x(i)/L)^2)/(2*k_cu(T_h))-...
%        (T_h-T_c)*x(i)/L+T_h; 
% end
 
%----Property functions-------------
function[k]=k_cu(T)
%returns the thermal conductivity (W/m-K) given temperature (K)
Td=[500,400,300,250,200,150,125,100,90,80,70,60,55,50]; %temperature data (K)
kd=[4.31,4.15,3.99,4.04,4.11,4.24,4.34,4.71,4.98,5.43,6.25,7.83,...
    9.11,11.0]*100; %conductivity data (W/m-K)
k=interp1(Td,kd,T);
%k=200;

function[rho_e]=rho_e_cu(T)
%returns the electrical resistivity (ohm-m) given temperature (K)
Td=[500,400,300,250,200,150,125,100,90,80,70,60,55,50]; %temperature data (K)
rho_ed=[3.19,2.49,1.73,1.39,1.06,0.72,0.54,0.36,0.29,0.22,0.15,...
    0.098,0.076,0.057]/(1e6*100); %electrical resistivity data (ohm-m)
rho_e=interp1(Td,rho_ed,T);
%rho_e=1e-8;